%DECISIÓN DEL VAD.
%function vvad=vaddec(pvad,thvad)
%Entradas:
%pvad:potencia filtrada del vad.
%thvad:potencia umbral de decisión.
%Salidas:
%vvad:decisión del vad.
function vvad=vaddec(pvad,thvad)
if(pvad>thvad)
   vvad=1;
else
   vvad=0;
end